/* This example shows a pure Java client using the J-Integra pure Java-COM 
 * bridge to talk to the Bloomberg BLP Data Control. You can run this 
 * program on any machine that supports a standard JVM. 
 *
 * For information on J-Integra, and to download an evaluation copy, please 
 * see http://www.intrinsyc.com/products/j-integra.
 * 
 * Create a file called BloombergExample.java containing this Java code. 
 * Create a subdirectory called "blpdatax" under the directory containing 
 * this Java program.
 *
 * Generate the pure Java proxy files used by this program to access the
 * Bloomberg BLP Data Control by running the 'com2java' tool from the J-Integra 
 * 'bin' directory. Specify "blpdatax.dll" as the type library, "blpdatax" 
 * as the package name, and the blpdatax subdirectory you created above as the 
 * output directory. 
 *
 * You will also need to create a surrogate for "blpdatax.dll" using the 
 * setdllhost tool. Open a command prompt and 'cd' to the directory containing
 * the blpdatax.dll file. Enter the following command:
 * > setdllhost blpdatax.dll "Blpdatax"
 *
 * You may have to run DCOMCNFG and check that the DCOM settings for the new 
 * surrogate are configured properly. For more information on DCOM configuration,
 * please see http://www.intrinsyc.com/support/j-integra/doc/#remoteaccess.html.
 *
 * This example is courtesy of Mathew George of UBS Warburg: http://www.ubswarburg.com
 */

import blpdatax.*;

public class BloombergExample {
  public static void main(String[] args) {
    try { 
      Object returnedValues = null;
      Object[] bbgResultsArray = null;

      System.out.println("Accessing Bloomberg...");

      // Create the Bloomberg object
      IBlpData2 blp = new BlpData();

      // Products: An Object array of ISIN codes
      Object products = new Object[] {};

      // BloombergFields: A String array of fields we want Bloomberg to calculate values for
      // e.g. PX_BID, YLD_YTM_BID, CNVX_BID, DAYS_ACC, INT_ACC, etc.
      Object bloombergFields = new String[] {};

      // OverrideFields: An Object array of fields we want to override the values for
      // e.g. PX_BID, SETTLE_DT
      Object overrideFields = new Object[] {};

      // OverrideValues: An Object array of the values we want to assign to these overriden fields
      Object overrideValues = new Object[] {};

      // Call the subscribe method on this object, returning a 3-D array
      returnedValues = blp.getBLPSubscribe(products, bloombergFields, 
                                           overrideFields, overrideValues);

      System.out.println("Finished with Bloomberg...");

      // Work with the returned data
      bbgResultsArray = (Object[])returnedValues;
      Object[] productsArr = (Object[])products;
      String[] bloombergFieldsArr = (String[])bloombergFields;

      for(int i=0; i < productsArr.length; i++) {
        Object[] bbgResults = (Object[])bbgResultsArray[i];

        for(int j=0; j < bloombergFieldsArr.length; j++) {
          Object bbgValue = bbgResults[j];
          double resultValue = 0.0;
          if ( !(bbgValue instanceof String) ) {
            Double doubleValue = (Double)bbgValue;
            resultValue = doubleValue.doubleValue();
          }

          // Display the results for each product and field
          System.out.println("product[" + i + "]: " + productsArr[i]);
          System.out.println("bloombergField[" + j + "]: " + bloombergFieldsArr[j]);
          System.out.println("value: " + resultValue);
        }
      }
    } catch (Exception e) {
      e.printStackTrace();
    } finally {
      com.linar.jintegra.Cleaner.releaseAll();
    }
  }
}